import setuptools

setuptools.setup(
    name='matvey_ma', # Имя пакета
    version='0.0.1',  # Версия пакета
    author='Your Name',
    author_email='your@domain.com',
    description='My Package',
    packages=setuptools.find_packages(),
)